@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 from ocp_resources.cluster_role import ClusterRole
-from ocp_resources.resource import Resource
+from ocp_resources.resource import MissingRequiredArgumentError, Resource
 
 
 class ClusterRoleBinding(Resource):
@@ -30,7 +30,8 @@ class ClusterRoleBinding(Resource):
         super().to_dict()
         if not self.yaml_file:
             if not self.cluster_role:
-                raise ValueError("Passing yaml_file or parameter 'cluster_role' is required.")
+                raise MissingRequiredArgumentError(argument="cluster_role")
+
             self.res.setdefault("roleRef", {})
             self.res["roleRef"] = {
                 "apiGroup": self.api_group,
