@@ -1,5 +1,5 @@
 from ocp_resources.constants import TIMEOUT_4MINUTES
-from ocp_resources.resource import NamespacedResource
+from ocp_resources.resource import MissingRequiredArgumentError, NamespacedResource
 
 
 class EndpointSlice(NamespacedResource):
@@ -55,7 +55,8 @@ class EndpointSlice(NamespacedResource):
         super().to_dict()
         if not self.yaml_file:
             if not (self.address_type and self.endpoints):
-                raise ValueError("yaml_file or parameters 'address_type' and 'endpoints' are" " required.")
+                raise MissingRequiredArgumentError(argument="'address_type' and 'endpoints'")
+
             self.res.update({
                 "addressTypes": self.address_type,
                 "endpoints": self.endpoints,
